#
# spec file for package python-packaging
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-packaging
Version:        16.8
Release:        20.1
Summary:        Core utilities for Python packages
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/pypa/packaging
Source:         https://pypi.io/packages/source/p/packaging/packaging-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module six}
BuildRequires:  python-rpm-macros
# do not add setuptools dependency, this is now a dependency
# of setuptools. Ensure that all dependencies also don't depend
# on setuptools
# (at the moment, six and pyparsing are ok)
%if %{with test}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest}
%endif
# older versions produce:
#   File "/usr/lib/python2.7/site-packages/packaging/requirements.py", line 59, in <module>
#    MARKER_EXPR = originalTextFor(MARKER_EXPR())("marker")
# TypeError: __call__() takes exactly 2 arguments (1 given)
Requires:       python-pyparsing >= 2.2.0
Requires:       python-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Core utilities for Python packages

%prep
%setup -q -n packaging-%{version}

%build
%python_build

%install
%python_install
# ensure egg-info is a directory
%{python_expand rm %{buildroot}%{$python_sitelib}/*.egg-info
cp -r packaging.egg-info %{buildroot}%{$python_sitelib}/packaging-%{version}-py%{$python_version}.egg-info
}

%if %{with test}
%check
%python_exec %{_bindir}/py.test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.rst LICENSE README.rst
%{python_sitelib}/packaging
%{python_sitelib}/packaging-%{version}-py*.egg-info/

%changelog
* Tue May  2 2017 dmueller@suse.com
- fix pyparsing requirement
* Thu Feb 23 2017 jmatejek@suse.com
- update for single-spec
- drop setuptools dependency, as this is itself now a dependency
  of setuptools
- run tests conditionally, to minimize dependency tree
- ensure egg-info is a directory (distutils would install it as file)
* Fri Dec  2 2016 tbechtold@suse.com
- update to 16.8:
  * Fix markers that utilize ``in`` so that they render correctly.
  * Fix an erroneous test on Python RC releases.
* Wed May 25 2016 tbechtold@suse.com
- update to 16.7:
  * Add support for the deprecated ``python_implementation`` marker which was
    an undocumented setuptools marker in addition to the newer markers.
  * Add support for the deprecated, PEP 345 environment markers in addition to
    the newer markers.
* Tue Mar  8 2016 tbechtold@suse.com
- update to 16.5:
  * Fix a regression in parsing requirements with whitespaces between the comma
    separators.
  * Fix a regression in parsing requirements like ``foo (==4)``.
  * Fix a bug where ``packaging.requirements:Requirement`` was overly strict when
    matching legacy requirements.
  * Add a function that implements the name canonicalization from PEP 503.
  * Implement requirement specifiers from PEP 508.
  * Relicense so that packaging is available under *either* the Apache License,
    Version 2.0 or a 2 Clause BSD license.
  * Support installation of packaging when only distutils is available.
  * Fix ``==`` comparison when there is a prefix and a local version in play.
    (:issue:`41`).
  * Implement environment markers from PEP 508.
- Adjust Requires according to requires.txt
* Tue Aug 11 2015 tbechtold@suse.com
- update to 15.3:
  * Normalize post-release spellings for rev/r prefixes. :issue:`35`
* Thu Jun 25 2015 tbechtold@suse.com
- update to 15.2:
  * Fix an error where the arbitary specifier (``===``) was not correctly
    allowing pre-releases when it was being used.
  * Expose the specifier and version parts through properties on the
    ``Specifier`` classes.
  * Allow iterating over the ``SpecifierSet`` to get access to all of the
    ``Specifier`` instances.
  * Allow testing if a version is contained within a specifier via the ``in``
    operator.
* Thu Apr 23 2015 tbechtold@suse.com
- Initial packaging
